@@ -5,7 +5,7 @@
 // portable bitmap graphics (pbm), tagged image file format (tiff)
 // or JPEG (jpg).
 //
-// Copyright (C) 1998-2007 Peter Schaefer-Hutter and contributors ("THE AUTHORS")
+// Copyright (C) 1998-2008 Peter Schaefer-Hutter and contributors ("THE AUTHORS")
 //
 // Permission to use, copy, modify, distribute, and sell this software and
 // its documentation for any purpose is hereby granted without fee.
@@ -31,7 +31,7 @@
 //
 /*-RCS-Info----------------------------------------------------
 
- $Id: main.cpp,v 1.5 2007/10/07 19:01:20 pschaefer Exp $
+ $Id: main.cpp,v 1.6 2008/09/13 13:06:26 pschaefer Exp $
 
 ---RCS-Info--------------------------------------------------*/
 
@@ -83,11 +83,15 @@ int main( int argc, char *argv[] )
       return 0;
 
     const string& strOutSpec = proc.getOutSpec();
+
+    bool bStdOut = (strOutSpec == "-");
+    bool bQuiet = proc.beQuiet() || bStdOut;
+
     if (strOutSpec.length() && (strOutSpec != "-")) {
       if (proc.getFileCount() > 1) {
         // More than one input file -> interpret OutSpec as a directory
         if (!fs::exists(strOutSpec)) {           // Create directory, if necessary
-          if (!proc.beQuiet()) cout << endl << "Creating directory " << strOutSpec.c_str() << "." << endl;
+          if (!bQuiet) cout << endl << "Creating directory " << strOutSpec.c_str() << "." << endl;
           try {
             fs::create_directories(strOutSpec);
           }
@@ -112,7 +116,6 @@ int main( int argc, char *argv[] )
     {
       COutputFilter *pOut = NULL;
       CSffFile      *pInfile = NULL;
-      bool           bStdOut = (strOutSpec == "-");
       char           acNumber[10];
 
       try
@@ -121,12 +124,12 @@ int main( int argc, char *argv[] )
 
         CSffFile *pInfile = new CSffFile(pathInFileName.string());
         int nPageCount = pInfile->GetPageCount();
-        if (!proc.beQuiet()) 
+        if (!bQuiet)
           cout << "File " << pathInFileName.string()
                << " seems to have " << nPageCount << " page(s)." << endl;
         int nFileCountOut = nPageCount;
         time_t modTime = pInfile->GetModificationTime();
-        
+
         switch (proc.getOutputFormat())
         {
           case CCmdLineProcessor::fmt_bmp:
@@ -154,9 +157,17 @@ int main( int argc, char *argv[] )
           fileOut.OpenTemp();
           pOut->Init(&fileOut);
         }
+
         for (int nPage = 0; nPage < nPageCount; nPage++)
         {
-          if (!bStdOut) 
+          TSFFPage* pPage = pInfile->GetPage(nPage);
+          if (pPage->height <= 0) {
+            if (!bQuiet) {
+              cout << "Skipping page (no lines)." << endl;
+            }
+            continue;
+          }
+          if (!bStdOut)
           {
             if (pathOutFileName.string().length()) {
               // A fixed name was given, so use it as a base name
@@ -189,13 +200,11 @@ int main( int argc, char *argv[] )
             }
           }
 
-          TSFFPage* pPage = pInfile->GetPage(nPage);
-
           bool bIsLowRes = pInfile->IsLowRes(nPage);
           bool bDoubleLines = !proc.keepVRes() && bIsLowRes;
 
-          if (!proc.beQuiet()) {
-            if (!bStdOut && !((nPage > 0) && (nFileCountOut == 1))) {
+          if (!bQuiet) {
+            if (!((nPage > 0) && (nFileCountOut == 1))) {
               cout << "- Destination File " << outPath.string() << " : " << endl;
             }
             cout << "  Converting page " << nPage+1
@@ -211,7 +220,7 @@ int main( int argc, char *argv[] )
           if (!bStdOut && !((nPage > 0) && (nFileCountOut == 1))) {
             fileOut.Open(outPath.string(), "wb+");
             pOut->Init(&fileOut);
-          } 
+          }
 
           if (bDoubleLines) {
             pOut->BeginPage(nPage, pPage->width,
@@ -261,6 +270,7 @@ int main( int argc, char *argv[] )
             }
           }
           pOut->EndPage();
+
           if (!bStdOut) {
             if ((nFileCountOut > 1) || ((nFileCountOut == 1) && (nPage == nPageCount-1))) {
               fileOut.Close();
@@ -271,6 +281,7 @@ int main( int argc, char *argv[] )
             }
           }
         }
+
         if (bStdOut) {
           fileOut.DumpToStdOut();
           fileOut.Close();
@@ -278,6 +289,7 @@ int main( int argc, char *argv[] )
             pOut->Finalize();
           }
         }
+
       }
       catch (const std::exception & e) {
         cerr << "ERROR: " << pathInFileName.string() << ": " << e.what() << endl;
@@ -293,9 +305,9 @@ int main( int argc, char *argv[] )
       if (pInfile) {
         delete pInfile;
       }
-      if (!proc.beQuiet()) cout << endl;
+      if (!bQuiet) cout << endl;
     }
-    if (!proc.beQuiet()) cout << "Finished. " << endl << endl;
+    if (!bQuiet) cout << "Finished. " << endl << endl;
   }
   catch (const std::exception & e) {
     cerr << "ERROR: " << e.what() << endl;
